summaryrefslogtreecommitdiff
path: root/src/runtime/pprof/pprof_test.go
diff options
context:
space:
mode:
Diffstat (limited to 'src/runtime/pprof/pprof_test.go')
-rw-r--r--src/runtime/pprof/pprof_test.go8
1 files changed, 4 insertions, 4 deletions
diff --git a/src/runtime/pprof/pprof_test.go b/src/runtime/pprof/pprof_test.go
index 54f93f861..edd471a0c 100644
--- a/src/runtime/pprof/pprof_test.go
+++ b/src/runtime/pprof/pprof_test.go
@@ -23,12 +23,12 @@ import (
func cpuHogger(f func()) {
// We only need to get one 100 Hz clock tick, so we've got
// a 100x safety buffer.
// But do at least 2000 iterations (which should take about 400ms),
// otherwise TestCPUProfileMultithreaded can fail if only one
// thread is scheduled during the 1 second period.
t0 := time.Now()
- for i := 0; i < 2000 || time.Since(t0) < time.Second; i++ {
+ for i := 0; i < 500 || time.Since(t0) < 250*time.Millisecond; i++ {
f()
}
}
@@ -23,12 +23,12 @@ import (
func cpuHogger(f func()) {
// We only need to get one 100 Hz clock tick, so we've got
- // a 100x safety buffer.
- // But do at least 2000 iterations (which should take about 400ms),
+ // a 25x safety buffer.
+ // But do at least 500 iterations (which should take about 100ms),
// otherwise TestCPUProfileMultithreaded can fail if only one
@@ -23,12 +23,12 @@ import (
// otherwise TestCPUProfileMultithreaded can fail if only one
- // thread is scheduled during the 1 second period.
+ // thread is scheduled during the 250ms period.
t0 := time.Now()